/*
 * astime is an analogue clock utility for X Windows.
 *
 * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
 *
 * For the updates see http://bewoner.dma.be/Albert/afterstep/
 *
 * This software is distributed under GPL. For details see LICENSE file.
 */

#ifndef _astime_x_h_
#define _astime_x_h_

void initialize(int argc, char **argv,
                char *window_name,
                char *display_name,
                char *mainGeometry,
                int withdrawn,
                int iconic,
                int pushed_in);
void update();
void redraw();
void x_cleanup();

#endif

